OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "La sessió ha caducat inesperadament",
    "Provided email-address is not valid" : "L'adreça de correu no és vàlida",
    "%s has published the calendar »%s«" : "%s ha publicat el calendari «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Error inesperat en enviar el correu. Contacteu amb l'administrador.",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Us volem informar que %s ha publicat el calendari «%s».",
    "Open »%s«" : "Obre »%s«",
    "Cheers!" : "A reveure!",
    "Upcoming events" : "Propers esdeveniments",
    "Calendar" : "Calendari",
    "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
    "Previous day" : "Dia anterior",
    "Previous week" : "Setmana anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Dia següent",
    "Next week" : "Setmana següent",
    "Next month" : "Mes següent",
    "+ New event" : "Esdeveniment nou",
    "Today" : "Avui",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "List" : "Llista",
    "Untitled calendar" : "Calendari sense títol",
    "Edit name" : "Edita nom",
    "Saving name …" : "S'està desant el nom …",
    "Edit color" : "Edita color",
    "Saving color …" : "S'està desant el color …",
    "Copy private link" : "Copia l'enllaç privat",
    "Download" : "Baixa",
    "Unshare from me" : "Deixa de compartir",
    "Delete" : "Suprimeix",
    "An error occurred, unable to change visibility of the calendar." : "S'ha produït un error. No s'ha canviat la visibilitat del calendari.",
    "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
    "Calendar link copied to clipboard." : "S'ha copiat l'enllaç del calendari al porta-retalls.",
    "Calendar link could not be copied to clipboard." : "No s'ha pogut copiar l'enllaç del calendari al porta-retalls.",
    "An error occurred, unable to rename the calendar." : "S'ha produït un error. No s'ha canviat el nom del calendari.",
    "An error occurred, unable to change the calendar's color." : "S'ha produït un error. No s'ha canviat el color del calendari.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","S'està deixant de compartir el calendari en {countdown} segons"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","S'està suprimint el calendari en {countdown} segons"],
    "Share link" : "Enllaç de compartició",
    "Publish calendar" : "Publicar el calendari",
    "Publishing calendar" : "S'està publicant el calendari",
    "Copy public link" : "Copiar l'enllaç públic",
    "Send link to calendar via email" : "Enviar per correu l'enllaç al calendari",
    "Enter one address" : "Escriure una adreça",
    "Sending email …" : "S'està enviant el correu …",
    "Copy subscription link" : "Copiar l'enllaç de subscripció",
    "Copying link …" : "S'està copiant l'enllaç …",
    "Copied link" : "Enllaç copiat",
    "Could not copy link" : "No s'ha pogut copiar l'enllaç",
    "Copy embedding code" : "Copiar el codi per inserir",
    "Copying code …" : "S'està copiant el codi …",
    "Copied code" : "Codi copiat",
    "Could not copy code" : "No s'ha pogut copiar el codi",
    "Delete share link" : "Suprimeix l'enllaç de compartició",
    "Deleting share link …" : "S'està suprimint l'enllaç de compartició …",
    "An error occurred, unable to publish calendar." : "Ha succeït un error i no ha estat possible publicar el calendari.",
    "An error occurred, unable to send email." : "Ha succeït un error i no ha estat possible enviar el correu.",
    "Embed code copied to clipboard." : "S'ha copiat el codi al porta-retalls.",
    "Embed code could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls el codi d'inserció.",
    "Unpublishing calendar failed" : "Ha fallat la des-publicació del calendari",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "No users or groups" : "No hi ha usuaris ni grups",
    "can edit" : "pot editar-lo",
    "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Ha succeït un error i no s'ha pogut canviar la no-compartició del calendari.",
    "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
    "+ New calendar" : "+ Calendari nou",
    "New calendar" : "Calendari nou",
    "Creating calendar …" : "S'està creant el calendari …",
    "New calendar with task list" : "Nou calendari amb llista de tasques",
    "New subscription from link (read-only)" : "Nova subscripció des d'enllaç (només lectura)",
    "Creating subscription …" : "S'està creant la subscripció …",
    "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
    "Untitled event" : "Esdeveniment sense títol",
    "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
    "Import calendars" : "Importar calendaris",
    "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
    "Filename" : "Nom del fitxer",
    "Calendar to import into" : "Calendari a importar",
    "Cancel" : "Cancel·la",
    "_Import calendar_::_Import calendars_" : ["Importar calendari","Importa calendaris"],
    "{filename} is an unsupported file-type" : "{filename} és un tipus de fitxer no compatible amb aquesta aplicació",
    "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
    "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
    "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["S'ha importat amb èxit %n event","S'han importat amb èxit %n events."],
    "Automatic" : "Automàtic",
    "Automatic ({detected})" : "Automàtica ({detected})",
    "New setting was not saved successfully." : "No s'ha desat correctament la nova configuració.",
    "Shortcut overview" : "Descripció general de la drecera",
    "or" : "o",
    "Navigation" : "Navegació",
    "Previous period" : "Període anterior",
    "Next period" : "Següent període",
    "Views" : "Vistes",
    "Day view" : "Vista de dia",
    "Week view" : "Vista de setmana",
    "Month view" : "Vista de mes",
    "Actions" : "Accions",
    "Create event" : "Crea un esdeveniment",
    "Show shortcuts" : "Mostra les dreceres",
    "Enable birthday calendar" : "Activa el calendari d'aniversaris",
    "Show tasks in calendar" : "Mostra tasques al calendari",
    "Enable simplified editor" : "Activa l'editor simplificat",
    "Limit visible events per view" : "Limita el nombre d'esdeveniments visibles per vista",
    "Show weekends" : "Mostra els caps de setmana",
    "Show week numbers" : "Mostra el número de la setmana",
    "Copy primary CalDAV address" : "Copia l'adreça CalDEV primària",
    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
    "Show keyboard shortcuts" : "Mostra les tecles de drecera",
    "Settings & import" : "Paràmetres i importació",
    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
    "before at" : "abans a les",
    "Notification" : "Notificació",
    "Email" : "Correu",
    "Audio notification" : "Notificació de so",
    "Other notification" : "Altres notificacions",
    "Relative to event" : "En relació a l'event",
    "On date" : "A la data",
    "Edit time" : "Modifica l'hora",
    "Save time" : "Desar l'hora",
    "Remove reminder" : "Suprimeix el recordatori",
    "on" : "a",
    "at" : "a",
    "+ Add reminder" : "+ Afegeix un recordatori",
    "_second_::_seconds_" : ["segon","segons"],
    "_minute_::_minutes_" : ["minut","minuts"],
    "_hour_::_hours_" : ["hora","hores"],
    "_day_::_days_" : ["dia","dies"],
    "_week_::_weeks_" : ["setmana","setmanes"],
    "No reminders yet" : "Encara no hi ha recordatoris",
    "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
    "Free" : "Lliure",
    "Busy (tentative)" : "Ocupat (temptativament)",
    "Busy" : "Ocupat",
    "Out of office" : "Fora de la oficina",
    "Unknown" : "Desconegut",
    "Create Talk room for this event" : "Crear una sala a Talk per a aquest event",
    "Show busy times" : "Mostra els horaris ocupats",
    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala del Talk a la descripció de l'event.",
    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
    "Chairperson" : "S'està convocant",
    "Required participant" : "Participant necessari",
    "Optional participant" : "Participant opcional",
    "Non-participant" : "No-participant",
    "Remove attendee" : "Treu el participant",
    "No match found" : "No s'ha trobat res",
    "No attendees yet" : "Encara sense participants",
    "(organizer)" : "(organitzador)",
    "Remove color" : "Treu el color",
    "Event title" : "Títol de l'event",
    "All day" : "Tot el dia",
    "from {startDate}" : "del {startDate}",
    "from {startDate} at {startTime}" : "de {startDate} a {startTime}",
    "to {endDate}" : "fins al {endDate}",
    "to {endDate} at {endTime}" : "fins al {endDate} a les {endTime}",
    "End repeat" : "Finalitza la repetició",
    "Select to end repeat" : "Seleccioneu per finalitzar repetició",
    "never" : "mai",
    "on date" : "a temps",
    "after" : "després de",
    "_time_::_times_" : ["hora","hores"],
    "first" : "primer",
    "third" : "tercer",
    "fourth" : "quart",
    "fifth" : "cinquè",
    "second to last" : "penúltim",
    "last" : "últim",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
    "Repeat" : "Repeteix",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Per dia del mes",
    "On the" : "Al",
    "_month_::_months_" : ["mes","mesos"],
    "_year_::_years_" : ["any","anys"],
    "Monday" : "Dilluns",
    "weekday" : "dia de la setmana",
    "weekend day" : "dia de cap de setmana",
    "Summary" : "Resum",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest event no es del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
    "More" : "Més",
    "Save" : "Desa",
    "Update" : "Actualitza",
    "Update this occurrence" : "Actualitza aquesta ocurrència",
    "Update this and all future" : "Actualitza aquesta i les futures",
    "Public calendar does not exist" : "No existeix un calendari públic",
    "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
    "Please select a timezone:" : "Selecciona un fus horari",
    "Pick a time" : "Tria una hora",
    "Pick a date" : "Tria una data",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "a {formattedDate}",
    "on {formattedDate}" : "el {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "del {formattedDate} a les {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
    "Please enter a valid date" : "Si us plau, escriu una data vàlida",
    "Please enter a valid date and time" : "Si us plau, escriu una data i hora vàlides",
    "Type to search timezone" : "Comença a escriure per cercar un fus horari",
    "Personal" : "Personal",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "La detecció automàtica de zona horària ha establert que la vostra zona horària és UTC.\nAixò probablement és el resultat d'una mesura de seguretat del vostre navegador web.\nEstabliu la vostra zona horària manualment a la configuració del calendari.",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "No s'ha trobat la zona horària que heu establert ({timezoneId}) . Així que se us ha retornat a la UTC.\nDefiniu la vostra zona horària a la configuració i si us plau informeu d'aquest problema.",
    "No more events today" : "Avui no hi ha més esdeveniments",
    "No upcoming events" : "No hi ha propers esdeveniments",
    "Create a new event" : "Crea un esdeveniment nou",
    "[Today]" : "[Avui]",
    "[Tomorrow]" : "[Demà]",
    "[Yesterday]" : "[Ahir]",
    "[Last] dddd" : "[Últim] dddd",
    "Event does not exist" : "L'esdeveniment no existeix",
    "Delete this occurrence" : "Suprimeix aquesta ocurrència",
    "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
    "Details" : "Detalls",
    "Attendees" : "Assistents",
    "Reminders" : "Recordatoris",
    "Close" : "Tanca",
    "Show more details" : "Mostra'n més detalls",
    "Subscribe to {name}" : "Subscriure a {name}",
    "Download {name}" : "Baixa {name}",
    "Anniversary" : "Commemoració",
    "Appointment" : "Cita",
    "Business" : "Negocis",
    "Education" : "Formació",
    "Holiday" : "Vacances",
    "Meeting" : "Reunió",
    "Miscellaneous" : "Miscel·lània",
    "Non-working hours" : "Hores fora de la feina",
    "Not in office" : "Fora de la oficina",
    "Phone call" : "Trucada telefònica",
    "Sick day" : "Malaltia",
    "Special occasion" : "Ocasió especial",
    "Travel" : "Viatge",
    "Vacation" : "Vacances",
    "Midnight on the day the event starts" : "Mitjanit del dia que comença l'event",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia abans de l'event a les {formattedHourMinute}","%n dies abans de l'event a les {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n setmana abans de l'event a les  {formattedHourMinute}","%n setmanes abans de l'event a les {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "el dia de l'event a les {formattedHourMinute}",
    "at the event's start" : "a l'inici de l'event",
    "at the event's end" : "al final de l'event",
    "{time} before the event starts" : "{time} abans de que comenci l'event",
    "{time} before the event ends" : "{time} abans de que acabi l'event",
    "{time} after the event starts" : "{time} després de que comenci l'event",
    "{time} after the event ends" : "{time} després de que acabi l'event",
    "on {time}" : "a les {time}",
    "on {time} ({timezoneId})" : "a les {time} ({timezoneId})",
    "Week {number} of {year}" : "Setmana {number} del {year}",
    "Does not repeat" : "No repetir",
    "Daily" : "Diàriament",
    "Weekly" : "Setmanalment",
    "Monthly" : "Mensualment",
    "Yearly" : "Anualment",
    "_Every %n day_::_Every %n days_" : ["Cada %n dia","Cada %n dies"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanes"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n mesos"],
    "_Every %n year_::_Every %n years_" : ["Cada %n any","Cada %n anys"],
    "_on {weekday}_::_on {weekdays}_" : ["el {weekday}","els {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["el dia {dayOfMonthList}","els dies {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "al {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "al {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "al {monthNames} al {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "fins el {untilDate}",
    "_%n time_::_%n times_" : ["%n vegada","%n vegades"],
    "Untitled task" : "Tasca sense títol",
    "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
    "W" : "S",
    "%n more" : "%n més",
    "No events to display" : "No hi ha esdeveniments per visualitzar",
    "_+%n more_::_+%n more_" : ["+%n més","+%n més"],
    "No events" : "Cap esdeveniment",
    "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
    "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
    "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
    "When shared show" : "Mostrar a compartits",
    "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
    "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
    "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
    "Location" : "Ubicació",
    "Add a location" : "Afegeix una ubicació",
    "Description" : "Descripció",
    "Add a description" : "Afegir una descripció",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Tentative" : "Provisional",
    "Canceled" : "Cancel·lat",
    "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'event.",
    "Show as" : "Mostra com",
    "Take this event into account when calculating free-busy information." : "Tenir en compte aquest event quan es calculi informació sobre disponibilitat-ocupació.",
    "Categories" : "Categories",
    "Categories help you to structure and organize your events." : "Les categories us ajuden a estructurar i organitzar els vostres events.",
    "Search or add categories" : "Cercar o afegir categories",
    "Add this as a new category" : "Afegeix-ho com una nova categoria",
    "Custom color" : "Color a mida",
    "Special color of this event. Overrides the calendar-color." : "Color especial per a aquest event. Sobreescriu el color del calendari.",
    "Chat room for event" : "Sala de xat per l'event",
    "Imported {filename}" : "{filename} importat",
    "Meditation" : "Meditació",
    "Relaxing" : "Relax",
    "Relax" : "Relax",
    "Presentation" : "Presentació",
    "Present" : "Regal",
    "Camping" : "Acampada",
    "Camp" : "Campament",
    "Movie" : "Pel·lícula",
    "Cinema" : "Sala de cinema",
    "Graduation" : "Graduació",
    "Brainstorm" : "Pluja d'idees",
    "Baseball" : "Beisbol",
    "Meet" : "Reunió",
    "Planning" : "Planificació",
    "Pointing" : "Apuntant",
    "Retrospective" : "Retrospectiva",
    "Review" : "Revisa",
    "Office" : "Oficina",
    "Contributor week" : "Setmana del contribuïdor",
    "Mail" : "Correu electrònic",
    "Soccer" : "Futbol",
    "Football" : "Futbol americà",
    "Gaming" : "Jugar",
    "Drive" : "Conduir",
    "Bicycle" : "Bicicleta",
    "Cycle" : "Ciclisme",
    "Biking" : "Anar en bici",
    "Podcast" : "Podcast",
    "Basketball" : "Bàsquet",
    "Fishing" : "Pesca",
    "Hiking" : "Excursió",
    "Hike" : "Passejada",
    "Art" : "Art",
    "Exhibition" : "Exhibició",
    "Museum" : "Museu",
    "Pilates" : "Pilates",
    "Park" : "Parc",
    "Studying" : "Estudiar",
    "Doctor" : "Doctor",
    "Health" : "Salut",
    "Dentist" : "Dentista",
    "Interview" : "Entrevista",
    "Training" : "Entrenament",
    "Practice" : "Pràctica",
    "Sports" : "Esport",
    "Exercise" : "Exercici",
    "Work out" : "Entrenament",
    "Working out" : "Entrenar",
    "Gym" : "Gimnàs",
    "Barber" : "Barber",
    "Haircut" : "Perruqueria",
    "Exam" : "Examen",
    "Working" : "Feina",
    "New Years Eve" : "Cap d'any",
    "NYE" : "Cap d'any",
    "Fireworks" : "Focs artificials",
    "Running" : "Còrrer",
    "Go for a run" : "Sortir a còrrer",
    "Marathon" : "Marató",
    "Video-conference" : "Vídeo-conferència",
    "Conference-call" : "Trucada de conferència",
    "Video-call" : "Vídeo-trucada",
    "Video-chat" : "Vídeo-xat",
    "Video-meeting" : "Vídeo-reunió",
    "Call" : "Trucada",
    "Calling" : "Trucar",
    "Christmas" : "Nadal",
    "Conference" : "Conferència",
    "Pizza" : "Pizza",
    "Travelling" : "Viatjar",
    "Journey" : "Viatge",
    "Collaborate" : "Col·laborar",
    "Pair" : "Parella",
    "Lecture" : "Lectura",
    "Seminar" : "Seminari",
    "Photograph" : "Fotografia",
    "Party" : "Festa",
    "Celebration" : "Celebració",
    "Celebrate" : "Celebrar",
    "Shopping" : "Anar de compres",
    "Skate" : "Patinar",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Tasta de vins",
    "Golf" : "Golf",
    "Dinner" : "Sopar",
    "Lunch" : "Dinar",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
